@@ -4,7 +4,7 @@ use App::GHPT::Wrapper::Ourperl;
 
 use v5.20;
 
-our $VERSION = '1.001000';
+our $VERSION = '2.000000';
 
 1;
 
@@ -22,7 +22,7 @@ App::GHPT - A command line tool to simplify using Github and Pivotal Tracker for
 
 =head1 VERSION
 
-version 1.001000
+version 2.000000
 
 =head1 SYNOPSIS
 
@@ -89,21 +89,22 @@ Change the PT story's status to "Delivered".
 
 =head1 SETUP
 
-=head2 hub
+=head2 GitHub config
 
-You should first set up C<hub>. It's available at L<https://hub.github.com>
-and has installation instructions there.
+You'll need to tell git about your GitHub account:
 
-After installation, tell git config about it and check that it's working.
+    git config --global submit-work.github.token gh_ae158fa0dc6570c8403f04bd35738d81
 
-    git config --global --add hub.host github.com
-    hub issue
+This is a GitHub personal access token.
 
-(You'll need your GitHub and/or GHE credentials.)
+You can alternatively provide the token via the C<GITHUB_TOKEN> environment variable.
 
-=head2 pt config
+For compatibility with prior versions, the configuration file for C<hub> will be
+used if the above are not set.
 
-You'll also need to tell git about your PT account:
+=head2 Pivotal Tracker config
+
+You'll also need to tell git about your Pivotal Tracker account:
 
     git config --global submit-work.pivotaltracker.username thor
     git config --global submit-work.pivotaltracker.token ae158fa0dc6570c8403f04bd35738d81
@@ -111,7 +112,9 @@ You'll also need to tell git about your PT account:
 Your actual username and token can be found at
 L<https://www.pivotaltracker.com/profile>.
 
-You can alternatively provide the token via the C<PIVOTALTRACKER_TOKEN> environment variable.
+You can alternatively provide your username via the C<PIVOTALTRACKER_USERNAME>
+environment variable and your token via the C<PIVOTALTRACKER_TOKEN> environment
+variable.
 
 =head1 CREATING PULL REQUEST QUESTIONS
 
@@ -121,9 +124,10 @@ C<ask>. See that role's documentation for details.
 
 By default, this tool looks for modules that have a package name beginning
 with C<App::GHPT::WorkSubmitter::Question> to find question classes. However,
-you can configure one or more alternative namespaces by setting the git config
-key C<submit-work.question-namespaces>. This should be a space-separated list
-of namespaces under which questions can live.
+you can configure one or more alternative namespaces by setting the
+C<APP_GHPT_QUESTION_NAMESPACES> environment variable or the
+C<submit-work.question-namespaces> Git config key. This should be a
+space-separated list of namespaces under which questions can live.
 
 =head1 REQUESTER NAME IN PULL REQUESTS
 
@@ -131,8 +135,9 @@ By default, the name of the PT story's requester will be included in the pull
 request text. This is helpful if you relay your project's PRs to Slack, as the
 requester can get alerted when their name is used.
 
-If you want to disable this, set the git config key
-C<submit-work.include-requester-name-in-pr> to C<0>.
+If you want to disable this, set the C<APP_GHPT_INCLUDE_REQUESTER_NAME_IN_PR>
+environment variable or the C<submit-work.include-requester-name-in-pr> Git
+config key to C<0>.
 
 =head1 COMMAND LINE OPTIONS
 
@@ -146,7 +151,7 @@ want to limit this to just one.
 
 =head2 --base branch
 
-The branch against which the PR should be made. This defaults to the master
+The branch against which the PR should be made. This defaults to the main
 branch.
 
 =head2 --dry-run
@@ -156,20 +161,6 @@ created.
 
 =head1 TROUBLESHOOTING
 
-=head2 Bad Credentials
-
-When hub is first used to connect to GitHub/GitHub Enterprise, hub requires a
-name and password that it uses to generate an OAuth token and stores it in
-C<~/.config/hub>. If you have not used hub yet, this script will exit with:
-
-    $ gh-pt.pl
-    Error creating pull request: Unauthorized (HTTP 401)
-    Bad credentials
-
-The fix is to regenerate the OAuth token. Delete the C<~/.config/hub> file if
-you've got one, and then run a C<hub> command manually, such as
-C<hub browse>. After authenticating, you should be able to use this script.
-
 =head2 "No started stories found"
 
 If you get this message but you definitely have stories which are in the
@@ -180,8 +171,6 @@ config --global --get-regexp '^submit-work'>
 
 =head1 BUGS
 
-This requires 'hub' to be installed and configured.
-
 A fatal error may occur if your branch exists locally, but you haven't pushed it yet.
 
 You may also get a warning like below, but this shouldn't impact the creation of your pull request.
@@ -206,7 +195,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Florian Ragwitz gabe Greg Oschwald Kevin Phair Mark Fowler Narsimham Chelluri Patrick Cronin William Storey
+=for stopwords Dave Rolsky Florian Ragwitz gabe Greg Oschwald Kevin Phair Mark Fowler Narsimham Chelluri Nick Logan Patrick Cronin William Storey
 
 =over 4
 
@@ -240,6 +229,10 @@ Narsimham Chelluri <nchelluri@maxmind.com>
 
 =item *
 
+Nick Logan <nlogan@gmail.com>
+
+=item *
+
 Patrick Cronin <pcronin@maxmind.com>
 
 =item *
@@ -250,7 +243,7 @@ William Storey <wstorey@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by MaxMind, Inc.
+This software is Copyright (c) 2022 by MaxMind, Inc.
 
 This is free software, licensed under:
 
